@@ -20,7 +20,7 @@
 #include "gl-application.h"
 
 #include <glib/gi18n.h>
-#include <libhandy-1/handy.h>
+#include <libadwaita-1/adwaita.h>
 
 #include "gl-categorylist.h"
 #include "gl-eventtoolbar.h"
@@ -65,7 +65,7 @@ on_new_window (GSimpleAction *action,
 
     window = gl_window_new (GTK_APPLICATION (application));
     gl_window_load_journal (GL_WINDOW (window), priv->journal);
-    gtk_widget_show (window);
+    gtk_window_present (GTK_WINDOW (window));
 }
 
 static void
@@ -75,19 +75,12 @@ on_help (GSimpleAction *action,
 {
     GtkApplication *application;
     GtkWindow *parent;
-    GError *error = NULL;
 
     application = GTK_APPLICATION (user_data);
     parent = gtk_application_get_active_window (application);
 
-    gtk_show_uri_on_window (parent, "help:gnome-logs",
-                            GDK_CURRENT_TIME, &error);
-
-    if (error)
-    {
-        g_debug ("Error while opening help: %s", error->message);
-        g_error_free (error);
-    }
+    gtk_show_uri (parent, "help:gnome-logs",
+                  GDK_CURRENT_TIME);
 }
 
 static void
@@ -97,12 +90,12 @@ on_about (GSimpleAction *action,
 {
     GtkApplication *application;
     GtkWindow *parent;
-    static const gchar* artists[] = {
+    static const gchar* designers[] = {
         "Jakub Steiner <jimmac@gmail.com>",
         "Lapo Calamandrei <calamandrei@gmail.com>",
         NULL
     };
-    static const gchar* authors[] = {
+    static const gchar* developers[] = {
         "David King <davidk@gnome.org>",
         "Jonathan Kang <jonathan121537@gmail.com>",
         NULL
@@ -110,16 +103,19 @@ on_about (GSimpleAction *action,
 
     application = GTK_APPLICATION (user_data);
     parent = gtk_application_get_active_window (GTK_APPLICATION (application));
-    gtk_show_about_dialog (parent,
-                           "authors", authors,
-                           "artists", artists,
+    adw_show_about_window (parent,
+                           "application-name", _("Logs"),
+                           "application-icon", "org.gnome.Logs",
+                           "developer-name", _("The GNOME Project"),
+                           "developers", developers,
+                           "designers", designers,
                            "translator-credits", _("translator-credits"),
-                           "comments", _("View and search logs"),
                            "copyright", "Copyright © 2013–2015 Red Hat, Inc.\nCopyright © 2014-2015 Jonathan Kang",
                            "license-type", GTK_LICENSE_GPL_3_0,
-                           "logo-icon-name", "org.gnome.Logs",
                            "version", PACKAGE_VERSION,
-                           "website", PACKAGE_URL, NULL);
+                           "website", PACKAGE_URL,
+                           "issue-url", "https://gitlab.gnome.org/GNOME/gnome-logs/-/issues/new",
+                           NULL);
 }
 
 static void
@@ -165,14 +161,11 @@ on_monospace_font_name_changed (GSettings *settings,
         css_fragment = g_strconcat (".event-monospace ", css_desc, NULL);
 
         provider = gtk_css_provider_new ();
-        g_signal_connect (provider, "parsing-error",
-                          G_CALLBACK (gl_util_on_css_provider_parsing_error),
-                          NULL);
-        gtk_css_provider_load_from_data (provider, css_fragment, -1, NULL);
+        gtk_css_provider_load_from_data (provider, css_fragment, -1);
 
-        gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-                                                   GTK_STYLE_PROVIDER (provider),
-                                                   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+        gtk_style_context_add_provider_for_display (gdk_display_get_default (),
+                                                    GTK_STYLE_PROVIDER (provider),
+                                                    GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
         g_free (css_desc);
         g_free (css_fragment);
@@ -200,16 +193,16 @@ gl_application_startup (GApplication *application)
     /* Calls gtk_init() with no arguments. */
     G_APPLICATION_CLASS (gl_application_parent_class)->startup (application);
 
-    /* Initialize libhandy widgets and styling */
-    hdy_init ();
+    /* Initialize libadwaita widgets and styling */
+    adw_init ();
 
     /* gtk_init() calls setlocale(), so gettext must be called after that. */
     g_set_application_name (_(PACKAGE_NAME));
     gtk_window_set_default_icon_name (PACKAGE_TARNAME);
 
     /* Opt-in to color scheme user preference. */
-    hdy_style_manager_set_color_scheme (hdy_style_manager_get_default (),
-                                        HDY_COLOR_SCHEME_PREFER_LIGHT);
+    adw_style_manager_set_color_scheme (adw_style_manager_get_default (),
+                                        ADW_COLOR_SCHEME_PREFER_LIGHT);
 }
 
 static void
@@ -228,7 +221,7 @@ launch_window (GApplication *application)
 
     window = gl_window_new (GTK_APPLICATION (application));
     gl_window_load_journal (GL_WINDOW (window), priv->journal);
-    gtk_widget_show (window);
+    gtk_window_present (GTK_WINDOW (window));
     gtk_application_set_accels_for_action (GTK_APPLICATION (application),
                                            "win.close", close_accel);
     gtk_application_set_accels_for_action (GTK_APPLICATION (application),
