@@ -20,7 +20,7 @@
 
 #include <glib/gi18n.h>
 #include <glib-unix.h>
-#include <libhandy-1/handy.h>
+#include <libadwaita-1/adwaita.h>
 #include <stdlib.h>
 
 #include "gl-categorylist.h"
@@ -182,7 +182,6 @@ listbox_update_header_func (GtkListBoxRow *row,
         if (current == NULL)
         {
             current = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
-            gtk_widget_show (current);
             gtk_list_box_row_set_header (row, current);
         }
     }
@@ -194,13 +193,16 @@ listbox_update_header_func (GtkListBoxRow *row,
         if (current == NULL)
         {
             current = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
-            gtk_widget_show (current);
             gtk_list_box_row_set_header (row, current);
         }
     }
 }
 
-
+static void
+popover_closed (GtkPopover *popover)
+{
+    gtk_widget_unparent (GTK_WIDGET (popover));
+}
 
 static void
 on_listbox_row_activated (GtkListBox *listbox,
@@ -358,26 +360,21 @@ on_listbox_row_activated (GtkListBox *listbox,
         GtkWidget *event_detail_popover;
         GtkWidget *category_label;
         GtkWidget *time_label;
-        GtkStyleContext *context;
 
         event_detail_popover = gl_event_view_detail_new (priv->entry, priv->clock_format);
-        gtk_popover_set_relative_to (GTK_POPOVER (event_detail_popover), GTK_WIDGET (row));
+        gtk_widget_set_parent (event_detail_popover, GTK_WIDGET (row));
 
         category_label = gl_event_view_row_get_category_label (GL_EVENT_VIEW_ROW (row));
 
         if (category_label)
-        {
-            context = gtk_widget_get_style_context (category_label);
-            gtk_style_context_remove_class (context, "dim-label");
-        }
+            gtk_widget_remove_css_class (category_label, "dim-label");
 
         time_label = gl_event_view_row_get_time_label (GL_EVENT_VIEW_ROW (row));
-        context = gtk_widget_get_style_context (time_label);
-        gtk_style_context_remove_class (context, "dim-label");
+        gtk_widget_remove_css_class (time_label, "dim-label");
 
-        context = gtk_widget_get_style_context (GTK_WIDGET (row));
-        gtk_style_context_add_class (context, "popover-activated-row");
+        gtk_widget_add_css_class (GTK_WIDGET (row), "popover-activated-row");
 
+        g_signal_connect (event_detail_popover, "closed", G_CALLBACK (popover_closed), NULL);
         gtk_popover_popup (GTK_POPOVER (event_detail_popover));
     }
 }
@@ -414,29 +411,6 @@ gl_event_view_list_get_boot_ids (GlEventViewList *view)
     return gl_journal_model_get_boot_ids (priv->journal_model);
 }
 
-gboolean
-gl_event_view_list_handle_search_event (GlEventViewList *view,
-                                        GAction *action,
-                                        GdkEvent *event)
-{
-    GlEventViewListPrivate *priv;
-
-    priv = gl_event_view_list_get_instance_private (view);
-
-    if (g_action_get_enabled (action))
-    {
-        if (gtk_search_bar_handle_event (GTK_SEARCH_BAR (priv->event_search),
-                                         event) == GDK_EVENT_STOP)
-        {
-            g_action_change_state (action, g_variant_new_boolean (TRUE));
-
-            return GDK_EVENT_STOP;
-        }
-    }
-
-    return GDK_EVENT_PROPAGATE;
-}
-
 void
 gl_event_view_list_set_search_mode (GlEventViewList *view,
                                     gboolean state)
@@ -456,7 +430,7 @@ gl_event_view_list_set_search_mode (GlEventViewList *view,
     }
     else
     {
-        gtk_entry_set_text (GTK_ENTRY (priv->search_entry), "");
+        gtk_editable_set_text (GTK_EDITABLE (priv->search_entry), "");
     }
 }
 
@@ -465,14 +439,13 @@ gl_event_view_create_empty (G_GNUC_UNUSED GlEventViewList *view)
 {
     GtkWidget *status_page;
 
-    status_page = hdy_status_page_new ();
-    hdy_status_page_set_icon_name (HDY_STATUS_PAGE (status_page),
+    status_page = adw_status_page_new ();
+    gtk_widget_set_hexpand (status_page, TRUE);
+    adw_status_page_set_icon_name (ADW_STATUS_PAGE (status_page),
                                    "action-unavailable-symbolic");
     /* Translators: Shown when there are no (zero) results in the current
      * view. */
-    hdy_status_page_set_title (HDY_STATUS_PAGE (status_page), _("No Results"));
-
-    gtk_widget_show (status_page);
+    adw_status_page_set_title (ADW_STATUS_PAGE (status_page), _("No Results"));
 
     return status_page;
 }
@@ -881,7 +854,7 @@ on_search_entry_changed (GtkSearchEntry *entry,
 
     g_free (priv->search_text);
 
-    priv->search_text = g_strdup (gtk_entry_get_text (GTK_ENTRY (priv->search_entry)));
+    priv->search_text = g_strdup (gtk_editable_get_text (GTK_EDITABLE (priv->search_entry)));
 
     /* Create the query object */
     query = create_query_object (view);
@@ -896,14 +869,14 @@ on_search_bar_notify_search_mode_enabled (GtkSearchBar *search_bar,
                                           gpointer user_data)
 {
     GAction *search;
-    GtkWidget *toplevel;
+    GtkRoot *root;
     GActionMap *appwindow;
 
-    toplevel = gtk_widget_get_toplevel (GTK_WIDGET (user_data));
+    root = gtk_widget_get_root (GTK_WIDGET (user_data));
 
-    if (gtk_widget_is_toplevel (toplevel))
+    if (G_IS_ACTION_MAP (root))
     {
-        appwindow = G_ACTION_MAP (toplevel);
+        appwindow = G_ACTION_MAP (root);
         search = g_action_map_lookup_action (appwindow, "search");
     }
     else
@@ -1016,6 +989,21 @@ gl_event_view_list_finalize (GObject *object)
     G_OBJECT_CLASS (gl_event_view_list_parent_class)->finalize (object);
 }
 
+static void
+gl_event_view_list_realize (GtkWidget *widget)
+{
+    GlEventViewList *view = GL_EVENT_VIEW_LIST (widget);
+    GlEventViewListPrivate *priv = gl_event_view_list_get_instance_private (view);
+    GtkRoot *root;
+
+    GTK_WIDGET_CLASS (gl_event_view_list_parent_class)->realize (widget);
+
+    root = gtk_widget_get_root (widget);
+
+    gtk_search_bar_set_key_capture_widget (GTK_SEARCH_BAR (priv->event_search),
+                                           GTK_WIDGET (root));
+}
+
 static void
 gl_event_view_list_class_init (GlEventViewListClass *klass)
 {
@@ -1023,6 +1011,7 @@ gl_event_view_list_class_init (GlEventViewListClass *klass)
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
     gobject_class->finalize = gl_event_view_list_finalize;
+    widget_class->realize = gl_event_view_list_realize;
 
     gtk_widget_class_set_template_from_resource (widget_class,
                                                  "/org/gnome/Logs/gl-eventviewlist.ui");
@@ -1082,7 +1071,7 @@ gl_event_view_list_init (GlEventViewList *view)
                       G_CALLBACK (on_listbox_row_activated), GTK_BOX (view));
 
     gtk_search_bar_connect_entry (GTK_SEARCH_BAR (priv->event_search),
-                                  GTK_ENTRY (priv->search_entry));
+                                  GTK_EDITABLE (priv->search_entry));
 
     /* TODO: Monitor and propagate any GSettings changes. */
     settings = g_settings_new (DESKTOP_SCHEMA);
