@@ -47,6 +47,7 @@ typedef struct
     GtkWidget *category_label;
     GtkWidget *message_label;
     GtkWidget *time_label;
+    GtkWidget *old_parent;
 } GlEventViewRowPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (GlEventViewRow, gl_event_view_row, GTK_TYPE_LIST_BOX_ROW)
@@ -125,6 +126,9 @@ gl_event_view_row_finalize (GObject *object)
     GlEventViewRowPrivate *priv = gl_event_view_row_get_instance_private (row);
 
     g_clear_object (&priv->entry);
+    priv->old_parent = NULL;
+
+    G_OBJECT_CLASS (gl_event_view_row_parent_class)->finalize (object);
 }
 
 static void
@@ -254,7 +258,6 @@ gl_event_view_row_replace_newline (const gchar *message)
 static void
 gl_event_view_row_constructed (GObject *object)
 {
-    GtkStyleContext *context;
     GtkWidget *grid;
     gchar *time;
     const gchar *message;
@@ -275,11 +278,10 @@ gl_event_view_row_constructed (GObject *object)
 
     rtl = (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL);
 
-    context = gtk_widget_get_style_context (GTK_WIDGET (row));
-    gtk_style_context_add_class (context, "event");
+    gtk_widget_add_css_class (GTK_WIDGET (row), "event");
     grid = gtk_grid_new ();
     gtk_grid_set_column_spacing (GTK_GRID (grid), 6);
-    gtk_container_add (GTK_CONTAINER (row), grid);
+    gtk_list_box_row_set_child (GTK_LIST_BOX_ROW (row), grid);
 
     g_object_get (object,
                   "category", &category,
@@ -291,9 +293,8 @@ gl_event_view_row_constructed (GObject *object)
     {
         gl_event_view_row_construct_category_label (row, entry);
 
-        context = gtk_widget_get_style_context (GTK_WIDGET (priv->category_label));
-        gtk_style_context_add_class (context, "dim-label");
-        gtk_style_context_add_class (context, "event-monospace");
+        gtk_widget_add_css_class (GTK_WIDGET (priv->category_label), "dim-label");
+        gtk_widget_add_css_class (GTK_WIDGET (priv->category_label), "event-monospace");
         gtk_label_set_xalign (GTK_LABEL (priv->category_label), 0);
         gtk_grid_attach (GTK_GRID (grid), priv->category_label,
                          rtl ? 2 : 0, 0, 1, 1);
@@ -319,8 +320,7 @@ gl_event_view_row_constructed (GObject *object)
     }
 
     gtk_widget_set_direction (priv->message_label, GTK_TEXT_DIR_LTR);
-    context = gtk_widget_get_style_context (GTK_WIDGET (priv->message_label));
-    gtk_style_context_add_class (context, "event-monospace");
+    gtk_widget_add_css_class (GTK_WIDGET (priv->message_label), "event-monospace");
     gtk_widget_set_halign (priv->message_label, GTK_ALIGN_START);
     gtk_label_set_ellipsize (GTK_LABEL (priv->message_label),
                              PANGO_ELLIPSIZE_END);
@@ -336,9 +336,8 @@ gl_event_view_row_constructed (GObject *object)
 
         message_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
 
-        gtk_box_pack_start (GTK_BOX (message_box),
-                            priv->message_label,
-                            TRUE, TRUE, 2);
+        gtk_box_append (GTK_BOX (message_box),
+                        priv->message_label);
 
         compressed_entries = gl_row_entry_get_compressed_entries (row_entry);
         compressed_entries_string = g_strdup_printf ("%d", compressed_entries);
@@ -346,14 +345,12 @@ gl_event_view_row_constructed (GObject *object)
         compressed_entries_label = gtk_label_new (compressed_entries_string);
 
         gtk_widget_set_direction (compressed_entries_label, GTK_TEXT_DIR_LTR);
-        context = gtk_widget_get_style_context (GTK_WIDGET (compressed_entries_label));
-        gtk_style_context_add_class (context, "compressed-entries-label");
+        gtk_widget_add_css_class (GTK_WIDGET (compressed_entries_label), "compressed-entries-label");
         gtk_widget_set_halign (compressed_entries_label, GTK_ALIGN_START);
         gtk_label_set_xalign (GTK_LABEL (compressed_entries_label), 0);
 
-        gtk_box_pack_start (GTK_BOX (message_box),
-                            compressed_entries_label,
-                            TRUE, TRUE, 0);
+        gtk_box_append (GTK_BOX (message_box),
+                        compressed_entries_label);
 
         gtk_grid_attach (GTK_GRID (grid), message_box,
                          1, 0, 1, 1);
@@ -381,10 +378,9 @@ gl_event_view_row_constructed (GObject *object)
         priv->time_label = gtk_label_new ("      ");
     }
 
-    context = gtk_widget_get_style_context (GTK_WIDGET (priv->time_label));
-    gtk_style_context_add_class (context, "dim-label");
-    gtk_style_context_add_class (context, "event-monospace");
-    gtk_style_context_add_class (context, "event-time");
+    gtk_widget_add_css_class (GTK_WIDGET (priv->time_label), "dim-label");
+    gtk_widget_add_css_class (GTK_WIDGET (priv->time_label), "event-monospace");
+    gtk_widget_add_css_class (GTK_WIDGET (priv->time_label), "event-time");
     gtk_widget_set_halign (priv->time_label, GTK_ALIGN_END);
     gtk_widget_set_hexpand (priv->time_label, TRUE);
     gtk_label_set_xalign (GTK_LABEL (priv->time_label), 1);
@@ -393,28 +389,27 @@ gl_event_view_row_constructed (GObject *object)
     g_free (time);
     g_object_unref (tmp_entry);
 
-    gtk_widget_show_all (GTK_WIDGET (row));
-
     G_OBJECT_CLASS (gl_event_view_row_parent_class)->constructed (object);
 }
 
 /* Hide the rows to be compressed */
 static void
-on_parent_set (GtkWidget *widget,
-               GtkWidget *old_parent,
-               gpointer   user_data)
+on_parent_set (GtkWidget *widget)
 {
-    GlEventViewRow *row = GL_EVENT_VIEW_ROW (user_data);
+    GlEventViewRow *row = GL_EVENT_VIEW_ROW (widget);
     GlEventViewRowPrivate *priv;
 
     priv = gl_event_view_row_get_instance_private (row);
 
     /* Execute only if the parent was not set earlier at all */
-    if (old_parent == NULL &&
+    if (priv->old_parent == NULL &&
         gl_row_entry_get_row_type (priv->entry) == GL_ROW_ENTRY_TYPE_COMPRESSED)
     {
         gtk_widget_hide (widget);
     }
+
+    if (gtk_widget_get_parent (GTK_WIDGET (row)))
+        priv->old_parent = gtk_widget_get_parent (GTK_WIDGET (row));
 }
 
 static void
@@ -460,8 +455,8 @@ gl_event_view_row_init (GlEventViewRow *row)
     /* The widgets are initialized in gl_event_view_row_constructed (), because
      * at _init() time the construct-only properties have not been set. */
 
-    g_signal_connect (row, "parent-set",
-                      G_CALLBACK (on_parent_set), row);
+    g_signal_connect (row, "notify::parent",
+                      G_CALLBACK (on_parent_set), NULL);
 }
 
 GlRowEntry *
